CREATE TABLE EmployeeCategory
(
  EmployeeCategory                 NVARCHAR2(50),
     CONSTRAINT pk_EmployeeCategory PRIMARY KEY (EmployeeCategory) 
)
;

CREATE TABLE DrugListings
(
  SeqNo                           NUMBER,
  LabelCode                       NVARCHAR2(250),
  ProdCode                        NVARCHAR2(250),
  Strength                        NVARCHAR2(100),
  Units                           NVARCHAR2(100),
  Rx_OTC                          NVARCHAR2(50),
  TradeName                       NVARCHAR2(250),
    CONSTRAINT pk_DrugListings PRIMARY KEY (SeqNo)
);
 
CREATE TABLE ICD10ProcedureCodes
(
  ICD10PCS                         NVARCHAR2(50),
  Description                      NVARCHAR2(500),
  BaseCost                         NUMBER(15,4),
  PhysicianRole                    NUMBER(10,4),
  TechnicianRole                   NUMBER(10,4),
  PhysicianAssistant               NVARCHAR2(4) NULL,
     CONSTRAINT pk_ICD10ProcedureCodes PRIMARY KEY (ICD10PCS) 
);

CREATE TABLE ICD10DiagnosisCodes
(
  ICD10CM                          NVARCHAR2(50),
  Description                      NVARCHAR2(500),
     CONSTRAINT pk_ICD10DiagnosisCodes PRIMARY KEY (ICD10CM) 
);
 
CREATE TABLE Patient
(
  PatientID                        INTEGER,
  LastName                         NVARCHAR2(50),
  FirstName                        NVARCHAR2(50),
  DateOfBirth                      DATE,
  Gender                           NVARCHAR2(50),
  Telephone                        NVARCHAR2(50),
  Address                          NVARCHAR2(50),
  City                             NVARCHAR2(50),
  State                            NVARCHAR2(50),
  ZIPCode                          NVARCHAR2(50),
  Race                             NUMBER(2),
  TobaccoUse                       NUMBER(1),
     CONSTRAINT pk_Patient PRIMARY KEY (PatientID) 
)
;
CREATE SEQUENCE sq_Patient INCREMENT BY 1 START WITH 1;

CREATE TABLE Employee
(
  EmployeeID                       INTEGER,
  LastName                         NVARCHAR2(50),
  FirstName                        NVARCHAR2(50),
  EmployeeCategory                 NVARCHAR2(50),
  DateHired                        DATE,
  DateLeft                         DATE,
  EmergencyPhone                   NVARCHAR2(50),
     CONSTRAINT pk_Employee PRIMARY KEY (EmployeeID), 
     CONSTRAINT fk_Employee_EmployeeCategory FOREIGN KEY (EmployeeCategory)
        REFERENCES EmployeeCategory (EmployeeCategory) 
        ON DELETE CASCADE 
)
;
CREATE SEQUENCE sq_Employee INCREMENT BY 1 START WITH 1;

CREATE TABLE EmployeeVacation
(
  EmployeeID                     INTEGER,
  VacationStart                  DATE,
  VacationEnd                    DATE,
    CONSTRAINT pk_EmployeeVacation PRIMARY KEY (EmployeeID, VacationStart),
    CONSTRAINT fk_EmployeeVac_Employee FOREIGN KEY (EmployeeID)
       REFERENCES Employee (EmployeeID)
       ON DELETE CASCADE
)
;

CREATE TABLE Visit
(
  VisitID                          INTEGER,
  PatientID                        INTEGER,
  VisitDate                        DATE,
  InsuranceCompany                 NVARCHAR2(50),
  InsuranceGroupCode               NVARCHAR2(50),
  InsuranceMemberCode              NVARCHAR2(50),
  PatientAmountPaid                DECIMAL(38,2),
  DateBillSubmitted                DATE,
  DateInsurancePaid                DATE,
  AmountInsurancePaid              DECIMAL(38,2),
  Diastolic                        NUMBER(4),
  Systolic                         NUMBER(4),
     CONSTRAINT pk_Visit PRIMARY KEY (VisitID), 
     CONSTRAINT fk_Visit_Patient FOREIGN KEY (PatientID)
        REFERENCES Patient (PatientID) 
        ON DELETE CASCADE 
)
;
CREATE SEQUENCE sq_Visit INCREMENT BY 1 START WITH 1;
 
CREATE TABLE VisitProcedures
(
  VisitProcedureID                 INTEGER,
  VisitID                          INTEGER,
  ICD10PCS                         NVARCHAR2(50),
  "Comment"                        NVARCHAR2(500),
  EmployeeID                       INTEGER,
  AmountCharged                    DECIMAL(38,2),
  ICD9Procedure                    NVARCHAR2(50),
     CONSTRAINT pk_VisitProcedures PRIMARY KEY (VisitProcedureID), 
     CONSTRAINT fk_VisitProcedures_Visit FOREIGN KEY (VisitID)
        REFERENCES Visit (VisitID) 
        ON DELETE CASCADE, 
     CONSTRAINT fk_VisitProcedures_ICD10PCS FOREIGN KEY (ICD10PCS)
        REFERENCES ICD10ProcedureCodes (ICD10PCS) 
        ON DELETE CASCADE, 
     CONSTRAINT fk_VisitProcedure_Employee FOREIGN KEY (EmployeeID)
        REFERENCES Employee (EmployeeID) 
        ON DELETE CASCADE 
)
;

CREATE SEQUENCE sq_VisitProcedure INCREMENT BY 1 START WITH 1;
 
CREATE TABLE VisitDiagnoses
(
  VisitID                          INTEGER,
  ICD10CM                          NVARCHAR2(50),
  ICD9Diagnosis                    NVARCHAR2(50),
  Comments                         NVARCHAR2(250),
     CONSTRAINT pk_VisitDiagnoses PRIMARY KEY (VisitID, ICD10CM), 
     CONSTRAINT fk_VisitDiagnoses_ICD10CM FOREIGN KEY (ICD10CM)
        REFERENCES ICD10DiagnosisCodes (ICD10CM)
        ON DELETE CASCADE, 
     CONSTRAINT fk_VisitDiagnoses_Visit FOREIGN KEY (VisitID)
        REFERENCES Visit (VisitID) 
        ON DELETE CASCADE 
)
;

CREATE TABLE VisitMedications
(
  VisitID                           INTEGER,
  DrugSeqNo                         INTEGER,
  DrugCode                          NVARCHAR2(50),
  Comments                          NVARCHAR2(255),
    CONSTRAINT pk_VisitMedications PRIMARY KEY (VisitID, DrugSeqNo),
    CONSTRAINT fk_VisitMeds_Visit FOREIGN KEY (VisitID)
      REFERENCES Visit (VisitID)
      ON DELETE CASCADE
);

-- old tables and cross walks
CREATE TABLE ICD9ProcedureCodes
(
  ICD9Procedure                    NVARCHAR2(50),
  ShortDescription                 NVARCHAR2(150),
  SetDate                          DATE,
  BaseCost                         NUMBER(9,2),
  PhysicianRole                    NUMBER(5,2),
  TechnicianRole                   NUMBER(5,2),
  PhysicianAssistant               NCHAR(1),
     CONSTRAINT pk_ICD9ProcedureCodes PRIMARY KEY (ICD9Procedure) 
)
;
 
CREATE TABLE ICD9DiagnosisCodes
(
  ICD9Diagnosis                    NVARCHAR2(50),
  ShortDescription                 NVARCHAR2(150),
     CONSTRAINT pk_ICD9DiagnosisCodes PRIMARY KEY (ICD9Diagnosis) 
)
;

CREATE TABLE GEMICD9xICD10_CM
(
  ICD9CMS NVARCHAR2(50),
  ICD10CM NVARCHAR2(50),
  MatchCode integer
);

CREATE TABLE GEMICD9xICD10_PCS
(
  ICD9PCS NVARCHAR2(50),
  ICD10PCS NVARCHAR2(50),
  MatchCode integer NULL
);


COMMIT;
