CREATE TABLE EmployeeCategory_Ext
(
  EmployeeCategory NVARCHAR2(50)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by '\t'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('EmployeeCategory.csv')
)
	reject limit unlimited;

CREATE TABLE DrugListings_Ext
(
  SeqNo                           NUMBER,
  LabelCode                       NVARCHAR2(250),
  ProdCode                        NVARCHAR2(250),
  Strength                        NVARCHAR2(100),
  Units                           NVARCHAR2(100),
  Rx_OTC                          NVARCHAR2(50),
  TradeName                       NVARCHAR2(250)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by '\t'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('DrugListings.csv')
)
	reject limit unlimited;


CREATE TABLE ICD10ProcedureCodes_Ext
(
  ICD10PCS                         NVARCHAR2(50),
  Description                      NVARCHAR2(500),
  BaseCost                         NUMBER(15,4),
  PhysicianRole                    NUMBER(10,4),
  TechnicianRole                   NUMBER(10,4),
  PhysicianAssistant               NVARCHAR2(4) NULL
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by '\t'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('ICD10ProcedureCodes.csv')
)
	reject limit unlimited;

CREATE TABLE ICD10DiagnosisCodes_Ext
(
  ICD10CM                          NVARCHAR2(50),
  Description                      NVARCHAR2(500)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by '\t'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('ICD10DiagnosisCodes.csv')
)
	reject limit unlimited;


CREATE TABLE Patient_Ext
(
  PatientID                        INTEGER,
  LastName                         NVARCHAR2(50),
  FirstName                        NVARCHAR2(50),
  DateOfBirth                      DATE,
  Gender                           NVARCHAR2(50),
  Telephone                        NVARCHAR2(50),
  Address                          NVARCHAR2(50),
  City                             NVARCHAR2(50),
  State                            NVARCHAR2(50),
  ZIPCode                          NVARCHAR2(50),
  Race                             NUMBER(2),
  TobaccoUse                       NUMBER(1)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by '\t'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('Patient.csv')
)
	reject limit unlimited;


CREATE TABLE Employee_Ext
(
  EmployeeID                       INTEGER,
  LastName                         NVARCHAR2(50),
  FirstName                        NVARCHAR2(50),
  EmployeeCategory                 NVARCHAR2(50),
  DateHired                        DATE,
  DateLeft                         DATE,
  EmergencyPhone                   NVARCHAR2(50)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by '\t'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('Employee.csv')
)
	reject limit unlimited;


CREATE TABLE EmployeeVacation_Ext
(
  EmployeeID                     INTEGER,
  VacationStart                  DATE,
  VacationEnd                    DATE
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by '\t'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('EmployeeVacation.csv')
)
	reject limit unlimited;


CREATE TABLE Visit_Ext
(
  VisitID                          INTEGER,
  PatientID                        INTEGER,
  VisitDate                        DATE,
  InsuranceCompany                 NVARCHAR2(50),
  InsuranceGroupCode               NVARCHAR2(50),
  InsuranceMemberCode              NVARCHAR2(50),
  PatientAmountPaid                DECIMAL(38,2),
  DateBillSubmitted                DATE,
  DateInsurancePaid                DATE,
  AmountInsurancePaid              DECIMAL(38,2),
  Diastolic                        NUMBER(4),
  Systolic                         NUMBER(4)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by '\t'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('Visit.csv')
)
	reject limit unlimited;


CREATE TABLE VisitProcedures_Ext
(
  VisitProcedureID                 INTEGER,
  VisitID                          INTEGER,
  ICD10PCS                         NVARCHAR2(50),
  "Comment"                        NVARCHAR2(500),
  EmployeeID                       INTEGER,
  AmountCharged                    DECIMAL(38,2),
  ICD9Procedure                    NVARCHAR2(50)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by '\t'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('VisitProcedures.csv')
)
	reject limit unlimited;


CREATE TABLE VisitDiagnoses_Ext
(
  VisitID                          INTEGER,
  ICD10CM                          NVARCHAR2(50),
  ICD9Diagnosis                    NVARCHAR2(50),
  Comments                         NVARCHAR2(250)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by '\t'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('VisitDiagnoses.csv')
)
	reject limit unlimited;


CREATE TABLE VisitMedications_Ext
(
  VisitID                           INTEGER,
  DrugSeqNo                         INTEGER,
  DrugCode                          NVARCHAR2(50),
  Comments                          NVARCHAR2(255)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by '\t'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('VisitMedications.csv')
)
	reject limit unlimited;


CREATE TABLE ICD9ProcedureCodes_Ext
(
  ICD9Procedure                    NVARCHAR2(50),
  ShortDescription                 NVARCHAR2(150),
  SetDate                          DATE,
  BaseCost                         NUMBER(9,2),
  PhysicianRole                    NUMBER(5,2),
  TechnicianRole                   NUMBER(5,2),
  PhysicianAssistant               NCHAR(1)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by '\t'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('ICD9ProcedureCodes.csv')
)
	reject limit unlimited;


CREATE TABLE ICD9DiagnosisCodes_Ext
(
  ICD9Diagnosis                    NVARCHAR2(50),
  ShortDescription                 NVARCHAR2(150)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by '\t'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('ICD9DiagnosisCodes.csv')
)
	reject limit unlimited;


CREATE TABLE GEMICD9xICD10_CM_Ext
(
  ICD9CMS NVARCHAR2(50),
  ICD10CM NVARCHAR2(50),
  MatchCode integer
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by '\t'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('GEMICD9xICD10_CM.csv')
)
	reject limit unlimited;


CREATE TABLE GEMICD9xICD10_PCS_Ext
(
  ICD9PCS NVARCHAR2(50),
  ICD10PCS NVARCHAR2(50),
  MatchCode integer NULL
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by '\t'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('GEMICD9xICD10_PCS.csv')
)
	reject limit unlimited;

